@@ -5,7 +5,7 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
-from tkdev.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevAudio
+from tkdev.devplyer import set_auto_install_plyer, install_plyer, DevNotification
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
     Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
@@ -160,7 +160,7 @@ def Install_ALL(Basic=True, Preview: bool = False, Pypi="https://pypi.tuna.tsing
     Install("BlurWindow", Basic=Basic, Pypi=Pypi, Preview=Preview)
     Install("darkdetect", Basic=Basic, Pypi=Pypi, Preview=Preview)
     Install("tkcap", Basic=Basic, Pypi=Pypi, Preview=Preview)
-    Install("Deprecated", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("plyer", Basic=Basic, Pypi=Pypi, Preview=Preview)
 
 
 def UnInstall(Library):
@@ -1435,6 +1435,12 @@ class DevWindow(tk.Tk):
         self.titlebar(titlebar)
         return titlebar
 
+    def seed_notification(self, title: str = "", message: str = "", app_name: str = "Python", app_icon="",
+                          time_out: int = 0):
+        Notification = DevNotification(title=title, message=message, app_name=app_name, app_icon=app_icon,
+                                       timeout=time_out)
+        Notification.show()
+
     def dpi(self):
         """
         设置dpi高清晰度
@@ -1566,6 +1572,5 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
-    Notification = DevNotification()
-    Notification.show()
+    DevNotification().show()
     Window.mainloop()
